/* Set jQuery crossbrowser support */
jQuery.support.cors = true;

/* Init the onsweb object */
var onsweb = {};

onsweb.config = {
    ajax_root : '', /* Root where all ajax requests need togo to. */
    debug_mode : false, /* Set TRUE it will show debug information in de browser console. */
    show_splashscreen : true, /* Set TRUE, Show initial splashscreen durring content loading. */
    use_dummie_data : false, /* Set TRUE, it will use the data in data.js instead of an ajax call.*/
    authentication_items : true, /* Set TRUE, items that are secure will be checked on login details. */
    data : { /* Onsweb data config */
        force_reset : true, /* Set TRUE, forces refresh of localstorage data */
        reset_update_before : 8888888888
    }
};

/* Core object, all objects that require an init are called here */
onsweb.core = {
    init : function(){

        /* Initialize the screen */
        onsweb.screen.init();

        /* Init the loader*/
        onsweb.loader.init_loader();

        /* Initialize the data */
        onsweb.data.init();

        /* Initialize all translations */
        onsweb.translation.init();

        /* Init the menu */
        onsweb.menu.init();

        /* Get storage user data*/
        onsweb.plugins.auth.init();

    }
};

/* Create the onsweb screen object*/
onsweb.screen = {
    defaults: {
        div : {
            header : '#header',
            footer : '#footer',
            content : '#content',
            wrapper: '#wrapper',
            scroller: '#scroller'
        }
    },
    data : {
        obj: null,
        window : {
            width : null,
            height : null
        },

        footer : {
            item : null,
            height : null,
            width : null
        },
        header : {
            item : null,
            height : null,
            width : null
        },
        content : {
            item : null,
            height : null,
            width : null
        },
        scroller : {
            item : null,
            height : null,
            width : null
        },
        wrapper : {
            item : null,
            height : null,
            width : null
        },
        is_android : false,
        is_ios : false,
        user_agent : null,
        iscroll : null
    },
    methods : {
        init : function() {
            onsweb.screen.data.footer.item = $(onsweb.screen.defaults.div.footer);
            onsweb.screen.data.header.item = $(onsweb.screen.defaults.div.header);
            onsweb.screen.data.content.item = $(onsweb.screen.defaults.div.content);
            onsweb.screen.data.wrapper.item = $(onsweb.screen.defaults.div.wrapper);
            onsweb.screen.data.scroller.item = $(onsweb.screen.defaults.div.scroller);

            onsweb.screen.methods.run_init_functions();
        /* asif resize fix */

        },
        run_init_functions : function(){
            onsweb.screen.methods.init_dimensions();

            onsweb.screen.methods.init_browser();
            onsweb.screen.methods.init_css();
            onsweb.screen.methods.init_iscroll();
            onsweb.screen.methods.position_footer();
            onsweb.screen.methods.set_dimensions();
            onsweb.screen.methods.remove_address_bar();
            onsweb.screen.methods.bind_events();
            onsweb.screen.methods.refresh_iscroll();

        },
        init_dimensions : function() {
            /* Footer */
            onsweb.screen.data.footer.height = onsweb.screen.data.footer.item.outerHeight();
            onsweb.screen.data.footer.width = onsweb.screen.data.footer.item.width();

              /* Header */
            onsweb.screen.data.header.height = onsweb.screen.data.header.item.outerHeight();
            onsweb.screen.data.header.width = onsweb.screen.data.header.item.width();

            /* Content */
            onsweb.screen.data.content.height = onsweb.screen.data.content.item.outerHeight();
            onsweb.screen.data.content.width = onsweb.screen.data.content.item.width();

            /* Scroller */
            onsweb.screen.data.scroller.height = onsweb.screen.data.scroller.item.outerHeight();
            onsweb.screen.data.scroller.width = onsweb.screen.data.scroller.item.width();

            /* Wrapper */
            onsweb.screen.data.wrapper.height = onsweb.screen.data.wrapper.item.height();
            onsweb.screen.data.wrapper.width = onsweb.screen.data.wrapper.item.width();

            /* Window */
            onsweb.screen.data.window.width = $(window).width();
            onsweb.screen.data.window.height = $(window).height();
        },
        remove_address_bar : function()
        {
            if(onsweb.screen.data.is_ios)
            {
                setTimeout(function(){
                    // Hide the address bar!
                    window.scrollTo(0, 1);
                }, 0);
                window.scrollTo( 0, 1 );
            }
            else if( onsweb.screen.data.is_android)
            {
                window.scrollTo( 0, 1 );
            }
            else
            {
                /* overflow:auto scrolltop function */
                $('#wrapper').scrollTop(0);
            }
        },
        init_browser : function() {
            onsweb.screen.data.user_agent = navigator.userAgent.toLowerCase();
            onsweb.screen.data.is_ios = onsweb.screen.data.user_agent.match(/(iphone|ipod|ipad)/);
            onsweb.screen.data.is_ipad = onsweb.screen.data.user_agent.match(/(ipad)/);
            onsweb.screen.data.is_android = onsweb.screen.data.user_agent.match(/(android)/);

        },
        init_css : function() {
            if(onsweb.screen.data.is_ios)
            {
                onsweb.screen.data.header.item.css({
                    position: 'absolute'
                });
                onsweb.screen.data.footer.item.css({
                    position: 'absolute'
                });
                if(onsweb.screen.data.is_ipad)
                {
                    onsweb.screen.data.content.item.css({
                        'padding-bottom' : onsweb.screen.data.footer.height +onsweb.screen.data.header.height+ 'px'
                    });
                }
                else
                {
                    onsweb.screen.data.content.item.css({
                        'padding-bottom' : onsweb.screen.data.header.height+  'px'
                    });
                }

                onsweb.screen.data.wrapper.item.css({
                    height: onsweb.screen.data.content.height+'px'
                });
            }
            else if(onsweb.screen.data.is_android)
            {
                onsweb.screen.data.wrapper.item.css({
                    overflow: 'visible'
                });
                onsweb.screen.data.content.item.css({
                    'padding-bottom' : onsweb.screen.data.footer.height
                });
            }
        },
        init_iscroll : function (){
            if(onsweb.screen.data.is_ios)
            {
                document.addEventListener('touchmove', function (e) {
                    e.preventDefault();
                }, false);
                onsweb.screen.data.iscroll = new iScroll('wrapper',{
                    useTransform: false,
                    onBeforeScrollStart: function (e) {
                        var target = e.target;
                        while (target.nodeType != 1)
                        {
                            target = target.parentNode;
                        }

                        if (target.tagName != 'SELECT' && target.tagName != 'INPUT' && target.tagName != 'TEXTAREA')
                        {
                            e.preventDefault();
                        }
                    }
                });
            }
        },
        refresh_iscroll : function (){
            if(onsweb.screen.data.is_ios)
            {
                onsweb.screen.data.iscroll.refresh();
            }
        },
        scrolltop_iscroll : function(){
            if(onsweb.screen.data.is_ios)
            {
                onsweb.screen.data.iscroll.scrollTo(0,0,0);
            }
        },
        position_footer : function() {
            if(onsweb.screen.data.is_ios)
            {
                if(onsweb.screen.data.is_ipad)
                {
                    onsweb.screen.data.footer.item.css({
                        top: onsweb.screen.data.window.height- onsweb.screen.data.footer.height+1+'px'
                    });
                }
                else if(("standalone" in window.navigator) &&
                    window.navigator.standalone)
                    {
                    // When in full-screen mode, change position of footer
                    onsweb.screen.data.footer.item.css({
                        top: onsweb.screen.data.window.height+onsweb.screen.data.footer.height - 86+'px'
                    });
                }
                else
                {

                    onsweb.screen.data.footer.item.css({
                        top: onsweb.screen.data.window.height+onsweb.screen.data.footer.height-86+'px'
                    });
                }

            }

        },
        set_dimensions : function() {
            if(onsweb.screen.data.is_ios)
            {

             onsweb.screen.data.header.item.css({
                    width: onsweb.screen.data.window.width+'px'
                });
                onsweb.screen.data.footer.item.css({
                    width: onsweb.screen.data.window.width+'px'
                });
                onsweb.screen.data.wrapper.item.css({
                    width: onsweb.screen.data.window.width+'px',
                    height: onsweb.screen.data.window.height +'px'

                });

                onsweb.screen.data.content.item.css({
                    'min-height': (onsweb.screen.data.window.height - (onsweb.screen.data.footer.height + onsweb.screen.data.header.height))+ 5 +'px'
                });
                if(!onsweb.screen.data.is_ipad)
                {
                    onsweb.screen.data.content.item.css({
                        'padding-bottom': onsweb.screen.data.header.height+onsweb.screen.data.footer.height+'px'
                    });
                }

            }
            else if(onsweb.screen.data.is_android)
            {
                onsweb.screen.data.content.item.css({
                    'min-height': (onsweb.screen.data.window.height - ( onsweb.screen.data.header.height)) +'px'
                });
            }
            else
            {
                onsweb.screen.data.wrapper.item.css({
                    bottom: onsweb.screen.data.footer.height+'px'
                });
                onsweb.screen.data.content.item.css({
                    'min-height': (onsweb.screen.data.window.height - (onsweb.screen.data.footer.height + onsweb.screen.data.header.height)) +'px'
                });
            }
        },
        bind_events : function() {

            if(onsweb.screen.data.is_ios)
            {
                $(window).resize(function(){
                    onsweb.screen.methods.reinit_window();
                });
            }

            $(window).bind('hashchange', function(event) {
                onsweb.screen.methods.remove_address_bar();
                onsweb.screen.methods.refresh_iscroll();

            });
            onsweb.screen.data.content.item.bind('change', function(){

                onsweb.screen.methods.refresh_iscroll();
                onsweb.screen.methods.scrolltop_iscroll();
                onsweb.screen.methods.remove_address_bar();
            });
        },
        reinit_window : function(){

            onsweb.screen.methods.init_dimensions();
            onsweb.screen.methods.init_css();
            onsweb.screen.methods.position_footer();
            onsweb.screen.methods.set_dimensions();
            onsweb.screen.methods.remove_address_bar();
            onsweb.screen.methods.refresh_iscroll();
        },
        enable_horizontal_scroll : function(width){
            if(width > 0){
                onsweb.screen.data.scroller.item.css({
                    'width': width+'px'
                });
                onsweb.screen.data.content.item.css({
                    'width': width+'px'
                });
                onsweb.screen.data.wrapper.item.css({
                    'width': width+'px'
                });
                onsweb.screen.methods.reinit_window();
            }
        },
        disable_horizontal_scroll : function(){
            onsweb.screen.data.scroller.item.css({
                'width': '100%'
            });
            onsweb.screen.data.content.item.css({
                'width': ''
            });
            onsweb.screen.data.wrapper.item.css({
                'width': '100%'
            });
            onsweb.screen.methods.reinit_window();
        }
    },
    init : function(){
        this.methods.init();
    },
    enable_horizontal_scroll : function(width){
        this.methods.enable_horizontal_scroll(width);
    },
    disable_horizontal_scroll : function(){
        this.methods.disable_horizontal_scroll();
    }
};

onsweb.menu = {
    defaults : {
        history_navigation : 'browser',
        content : '#content',
        wrapper : '#wrapper',
        menu_item_class : 'o-menu-item',
        header : '#header',
        header_background_block : 'o-header-background-block',
        header_back_button_class: 'o-header-back-button',
        header_title_block_class : 'o-header-title-block',
        header_right_menu_class : 'o-header-right-menu',
        header_sub_menu_class : 'o-header-sub-menu',
        header_ball_icon_class : 'o-header-ball-icon',
        header_live_button_class :'o-header-live-button',
        footer : '#footer',
        has_submenu : false,
        sub_menu : {
            list_class : 'o-sub-menu-list',
            item_class : 'o-sub-menu-item',
            change_class : 'o-sub-menu-item-change',
            add_class : 'o-sub-menu-item-add'
        },
        change_class : 'o-sub-menu-item-change',
        add_class : 'o-sub-menu-item-add'
    },
    data : {
        obj: null,
        content_block : null,
        header_block : null,
        menu_json : {},
        menu_links : {},
        current_menu_item : false,
        menu_level : 0,
        header : {
            back_button : null,
            title_block : null,
            right_menu_block : null,
            sub_menu_block : null
        },
        init_url : false,
        menu_items : null
    },
    methods : {
        init : function() {
            onsweb.menu.data.obj = $(onsweb.menu.defaults.footer);
            onsweb.loader.start('onsweb_app_menu::init');
            onsweb.menu.data.content_block = $(onsweb.menu.defaults.content);
            onsweb.menu.data.header_block = $(onsweb.menu.defaults.header);
            this.init_header();
            this.clear_menu();
            this.bind_param_change();
            onsweb.menu.data.init_url = this.init_url();
            this.update_header();
            this.check_url();
            this.init_content_block();
            this.init_menu_json(onsweb.menu.data.menu_items);
        },
        init_content_block : function(){
            onsweb.banner.set_banner(onsweb.menu.data.current_menu_item);
            this.bind_content_change();
        },
        init_menu_json : function(json){
            onsweb.menu.data.menu_json = json;
            this.init_menu();
        },
        init_menu : function() {
            this.fill_menu();
            this.bind_menu_items();
        },
        init_header : function (){
            onsweb.menu.methods._create_basic_header();
            onsweb.menu.data.header.back_button = onsweb.menu.data.header_block.find('.'+onsweb.menu.defaults.header_back_button_class);
            onsweb.menu.data.header.ball_icon = onsweb.menu.data.header_block.find('.'+onsweb.menu.defaults.header_ball_icon_class);
            onsweb.menu.data.header.title_block = onsweb.menu.data.header_block.find('.'+onsweb.menu.defaults.header_title_block_class);
            onsweb.menu.data.header.right_menu_block = onsweb.menu.data.header_block.find('.'+onsweb.menu.defaults.header_right_menu_class);
            onsweb.menu.data.header.live_button = onsweb.menu.data.header_block.find('.'+onsweb.menu.defaults.header_live_button_class);
            onsweb.menu.data.header.sub_menu_block = onsweb.menu.data.header_block.find('.'+onsweb.menu.defaults.header_sub_menu_class);
            this.bind_header_events();
        },
        clear_menu : function (){
            onsweb.page_writer.clear_footer();
        },

        fill_menu : function (){
            onsweb.page_writer.fill_footer(onsweb.menu.methods._create_menu_list());
            onsweb.menu.data.obj.find('.'+onsweb.menu.defaults.menu_item_class+':first').addClass('first');
            onsweb.menu.data.obj.find('.'+onsweb.menu.defaults.menu_item_class+':last').addClass('last');
            onsweb.menu.data.obj.find('.'+onsweb.menu.defaults.menu_item_class).removeClass('active');
            onsweb.menu.set_active_class(onsweb.url.get_hash(1));

        },
        _create_basic_header : function(){
            onsweb.page_writer.fill_header(onsweb.template.view('menu','header',onsweb.menu.defaults));
        },
        _create_menu_list : function()
        {
            var items = {
                items : ''
            };
            $.each(onsweb.menu.data.menu_json,function(i,item){
                if(item.in_menu == 1){
                    items.items +=  onsweb.menu.methods._create_menu_list_item(item, i);
                }
            });
            return onsweb.template.view('menu','menu_list',items);
        },
        _create_menu_list_item : function(item, i)
        {
            onsweb.menu.data.menu_links[item.link]= {
                type : item.type
            };
            item.menu_item_class = onsweb.menu.defaults.menu_item_class;
            item.i = i;
            return onsweb.template.view('menu','menu_list_item',item);
        },
        bind_header_events : function (){
            onsweb.menu.data.header.right_menu_block.unbind().change(function(){
                if($(this).html() != '')
                {
                    $(this).show();
                }
                else
                {
                    $(this).hide();
                }
            });

            onsweb.menu.data.header.sub_menu_block.unbind().change(function(){
                if($(this).html() != '')
                {
                    $(this).show();
                }
                else
                {
                    $(this).hide();
                }
                $(onsweb.menu.defaults.wrapper).css({
                    top: onsweb.menu.data.header_block.outerHeight() +'px'
                });

            });
        },
        bind_menu_items : function (){
            onsweb.menu.data.obj.find('.'+onsweb.menu.defaults.menu_item_class).unbind('click').bind('click', function(){
                var link = $(this).attr('link');

                //onsweb.menu.data.obj.find('.'+onsweb.menu.defaults.menu_item_class).removeClass('active');
                //onsweb.menu.data.obj.find('.'+onsweb.menu.defaults.menu_item_class+'.'+link).addClass('active');
                onsweb.menu.set_active_class(link);


                if(link == onsweb.url.get_hash())
                {
                    onsweb.menu.data.content_block.html(' ');
                    onsweb.menu.methods.hash_change();
                }
                else
                {
                    onsweb.url.change_hash(link);
                }
            });
        },
        bind_param_change : function(){
            $(window).bind('hashchange', function() {
                if(onsweb.loader.start('onsweb_app_menu::hash_change') == true)
                {
                    $.doTimeout(100, function(){
                        onsweb.menu.methods.hash_change();
                    });
                }
            });
        },
        bind_content_change : function(){

        },
        hash_change : function()
        {
            onsweb.menu.bind_header_back_button('browser');
            onsweb.menu.data.has_submenu = false;
            onsweb.menu.data.init_url = onsweb.menu.methods.init_url();
            this.update_header();

            this.check_url();

            onsweb.banner.set_banner(onsweb.menu.data.current_menu_item);
            onsweb.menu.set_active_class(onsweb.url.get_hash(1));
        },

        check_url : function(){
            if(onsweb.menu.data.init_url)
            {
                if(onsweb.config.authentication_items && onsweb.menu.data.current_menu_item.is_secure == 1 && !onsweb.plugins.auth.is_logged_in()){
                    onsweb.console.warn('Not logged in. Will be redirected to login page');
                    /* Store current hash */
                    onsweb.plugins.auth.data.redirect_hash = onsweb.url.get_hash();
                    /* Redirect to login page */
                    onsweb.url.change_hash('login');
                } else {
                    if(onsweb.plugins[onsweb.menu.data.current_menu_item.plugin] != undefined && onsweb.plugins[onsweb.menu.data.current_menu_item.plugin][onsweb.menu.data.current_menu_item.func] != undefined){
                        try {
                            onsweb.plugins[onsweb.menu.data.current_menu_item.plugin][onsweb.menu.data.current_menu_item.func]();
                        } catch (e){
                            onsweb.console.warn('Error in plugin function! P:'+onsweb.menu.data.current_menu_item.plugin +' F:'+onsweb.menu.data.current_menu_item.func+ ' E:'+ e);
                            onsweb.page_writer.fill_content('<div class="error">'+gt('Oops er is een fout opgetreden.')+'</div>');
                        }

                        /* Bind links on the website */
                        onsweb.menu.bind_links();
                    } else {
                        onsweb.console.warn('Could not find menu item plugin and/or function! P:'+onsweb.menu.data.current_menu_item.plugin +' F:'+onsweb.menu.data.current_menu_item.func);
                        onsweb.page_writer.throw_404();
                    }
                }
            }
            else
            {
                onsweb.page_writer.throw_404();
            }
        },
        init_url : function (){
            var parts = onsweb.url.get_hash();

            if(parts == '')
            {
                parts[0] = 'home';
                /* Dirty fix for the page object */
                onsweb.url.change_hash('home');
            }
            onsweb.menu.data.current_menu_item = false;
            for(var i = 0; i < parts.length; i++)
            {
                if(onsweb.menu.data.current_menu_item == false)
                {
                    if(onsweb.menu.data.menu_items[parts[i]])
                    {
                        onsweb.menu.data.current_menu_item = onsweb.menu.data.menu_items[ parts[i]];
                    }
                    else
                    {
                        return false;
                    }
                }
                else
                {
                    if(onsweb.menu.data.current_menu_item.sub_menu != undefined && onsweb.menu.data.current_menu_item.sub_menu[parts[i]])
                    {
                        onsweb.menu.data.current_menu_item = onsweb.menu.data.current_menu_item.sub_menu[parts[i]];
                    }
                    else if(onsweb.menu.data.current_menu_item.dynamic_sub != undefined && onsweb.menu.data.current_menu_item.dynamic_sub == 1)
                    {
                        return true;
                    }
                    else
                    {
                        return false;
                    }
                }
            }
            onsweb.menu.data.menu_level = i;
            return true;
        },
        update_header : function() {
            onsweb.menu.methods.update_header_back_button();
            onsweb.menu.methods.update_header_title();
            onsweb.menu.methods.update_header_right_menu();
            onsweb.menu.methods.update_header_sub_menu();
            onsweb.menu.methods.update_header_live();
        },

        update_header_live : function(show){
            onsweb.screen.data.header.item.removeClass('livescore');
            onsweb.menu.data.header.live_button.hide();
        },

        update_header_back_button : function(){
            switch(onsweb.menu.defaults.history_navigation)
            {
                case 'browser':
                case 'level':
                default:
                    if($.param.fragment() === "match-overview" || $.param.fragment() === "nomatch" ){
                        onsweb.menu.data.header.back_button.show();
                        onsweb.menu.data.header.ball_icon.hide();
                    }else if(onsweb.url.get_hash(1) != onsweb.url.get_hash(2))
                    {
                        onsweb.menu.data.header.back_button.show();
                        onsweb.menu.data.header.ball_icon.hide();
                    }
                    else
                    {
                        onsweb.menu.data.header.back_button.hide();
                        onsweb.menu.data.header.ball_icon.show();
                    }
                    break;

            }
        },

        update_header_title: function() {
            onsweb.menu.data.header.title_block.html(onsweb.menu.data.current_menu_item.title);
        },
        update_header_right_menu : function(){
            onsweb.menu.data.header.right_menu_block.html('').triggerHandler('change');
        },
        update_header_sub_menu : function(){
            onsweb.menu.data.header.sub_menu_block.html('').triggerHandler('change');
        }

    },
    init : function(){
        this.data.menu_items = onsweb.data.get('menu');
        this.methods.init();
    },
    get_current_menu_item : function(){
        return onsweb.menu.data.current_menu_item;
    },
    get_sub_menu : function(menu_item){
        if(menu_item == undefined){
            menu_item = this.data.current_menu_item;
        }
        return this._create_sub_menu(menu_item);
    },

    bind_links : function(){
        $('.'+this.defaults.sub_menu.change_class).unbind('click').click(function(e){
            onsweb.url.change_hash($(this).attr('rel'));
			e.stopPropagation();
        });
        $('.'+this.defaults.sub_menu.add_class).unbind('click').click(function(e){
            onsweb.url.add_hash($(this).attr('rel'));
			e.stopPropagation();
        });
        $('.setup').unbind('click').click(function(){
            $('.'+onsweb.plugins.livescore.defaults.setup_overview_class).show();
             $('.gameplay').removeClass('active');
            $('.setup').addClass('active');
            $('.'+onsweb.plugins.livescore.defaults.event_overview_class).hide();
            onsweb.menu.set_header_title("Opstelling");
            onsweb.screen.methods.refresh_iscroll();
        });
        $('.gameplay').unbind('click').click(function(){
            $('.'+onsweb.plugins.livescore.defaults.setup_overview_class).hide();
            $('.'+onsweb.plugins.livescore.defaults.event_overview_class).show();
             $('.setup').removeClass('active');
            $('.gameplay').addClass('active');
            onsweb.menu.set_header_title("Spelverloop");
            onsweb.screen.methods.refresh_iscroll();
        });
    },
    _create_sub_menu : function(menu_item){
        if(menu_item.sub_menu == undefined ){
            onsweb.console.log('No Sub menu items found!');
            return '';
        } else {
            this.data.has_submenu = true;
            var items = {
                list_class : this.defaults.sub_menu.list_class,
                items : ''
            };
            $.each(menu_item.sub_menu, function(){
                var item = this;
                if(item.in_menu == 1){
                    item.rel = item.link;
                    item.item_class = onsweb.menu.defaults.sub_menu.add_class;

                    items.items += onsweb.template.view('menu', 'sub_menu_item', item);
                }
            });
            return onsweb.template.view('menu', 'sub_menu', items);
        }
    },
    set_header_right_menu : function(html){
        onsweb.menu.data.header.right_menu_block.html(html).triggerHandler('change');
    },
    set_header_live_button : function(html){
        onsweb.menu.data.header.live_button.html(html).triggerHandler('change');
    },
    set_header_title : function(t){
        if(t != ''){
            onsweb.menu.data.header.title_block.html(t);
        }
    },
    set_active_class : function(link){
        onsweb.menu.data.obj.find('.'+onsweb.menu.defaults.menu_item_class).removeClass('active');
        switch(link){
            default:
                onsweb.menu.data.obj.find('.'+onsweb.menu.defaults.menu_item_class+'.'+link).addClass('active');
                break;
            case 'login':
                onsweb.menu.data.obj.find('.'+onsweb.menu.defaults.menu_item_class+'.mijn-nhv').addClass('active');
                break;
        }
    },

    bind_header_back_button : function(type,hash){
        onsweb.console.log('binding back button. type: '+ type);
        onsweb.menu.data.header_block.find('.'+onsweb.menu.defaults.header_back_button_class).unbind('click').click(function(){
            switch(type)
            {
                default:
                case 'browser':
                    window.history.back()
                    break;

                case 'level':
                    if(onsweb.menu.data.menu_level <= 1)
                    {
                        hash = 'home';
                    }
                    else
                    {
                        var parts = onsweb.url.get_hash();
                        parts.pop()
                        hash = parts.join('/');
                    }
                    onsweb.url.change_hash(hash);
                    break;
                case 'go_hash':
                    onsweb.url.change_hash(hash);
                    break;
            }
        });
    }
};

/* ONSWEB TRANSLATION OBJECT */
onsweb.translation = {
    defaults : {},
    data : {
        translations : null
    },
    methods : {
        gt : function(key){
            return onsweb.translation.methods.get_translation(key);
        },
        get_translation : function(key){
            if(onsweb.translation.data.translations == null || onsweb.translation.data.translations[key] == undefined)
            {
                /* Push all unkown translations to the server when debug mode is enabled */
                if(onsweb.config.debug_mode){
                    onsweb.ajax.call('push_translation',{
                        key: key
                    });
                }

                return key;
            }
            else
            {
                return onsweb.translation.data.translations[key];
            }
        }
    },
    gt : function(key){
        onsweb.translation.methods.get_translation(key);
    },
    init : function(){
        onsweb.translation.data.translations = onsweb.data.get('translation');
    }
};

/* Simple function to get all translations */
function gt(key){
    return onsweb.translation.methods.gt(key);
}


/* ONSWEB LOADING OBJECT */
onsweb.loader = {
    defaults : {
        loading : {
            block_class : 'o-loading-block',
            image_class : 'o-loading-image',
            title_class : 'o-loading-title',
            block_center : 'o-loading-center-block'
        },
        splashscreen :{
            block_class : 'o-splashscreen'
        }
    },
    data : {
        html : null
    },
    methods : {
        init : function(){
            onsweb.loader.methods.create_loader_html();
            onsweb.loader.methods.parse_loading_div();
        },
        create_loader_html : function (){
            onsweb.loader.data.html = onsweb.template.view('loader','loader',onsweb.loader.defaults.loading);
        },
        start_loading : function(called_name){
            //onsweb.loader.methods.init();
            onsweb.console.log('starting loading screen. Called by: ' + called_name);
            onsweb.loader.methods.show_loading_div();
            var i = 0;
            while(onsweb.loader.methods.is_visible() != true)
            {
                onsweb.console.log('not visible looped: ' + i++);
            }

            return true;

        },
        stop_loading : function(called_name){

            onsweb.console.log('stopping loading screen. Called by: ' + called_name);
            if(onsweb.loader.methods.loading_running() == true)
            {
                onsweb.loader.methods.hide_loading_div();
            }
        },
        loading_running : function(){
            return $('.'+onsweb.loader.defaults.loading.block_center).length ==0 ? false : true;
        },
        parse_loading_div : function(){
            $('body').prepend(onsweb.loader.data.html);
            $('.'+onsweb.loader.defaults.loading.block_center).ajaxStart(function(){
                $(this).show();
            });
            $('.'+onsweb.loader.defaults.loading.block_center).ajaxStop(function(){
                $(this).hide();
            });
        },
        remove_loading_div : function(){
            $('.'+onsweb.loader.defaults.loading.block_center).remove();
        },
        show_loading_div : function(){
            $('.'+onsweb.loader.defaults.loading.block_center).addClass('nothidden').show();
        },
        hide_loading_div : function(){
            $('.'+onsweb.loader.defaults.loading.block_center).removeClass('nothidden').hide();
        },
        is_visible : function(){

            if($('.'+onsweb.loader.defaults.loading.block_center).hasClass('nothidden'))
            {
                return true;
            }
            else
            {
                return false;
            }
        }
    },
    start : function(called_name){
        return this.methods.start_loading(called_name);
    },
    stop : function(called_name){
        this.methods.stop_loading(called_name);

    },
    start_splashscreen : function(){
        onsweb.console.log('Show splashscreen');
        this.methods.start_splashscreen();
        return true;

    },
    stop_splashscreen : function(){
        this.methods.stop_splashscreen();
        onsweb.console.log('Remove splashscreen');
    },
    init_loader : function(){
        this.methods.init();
    }
};

onsweb.url = {

    defaults : {},
    data : {
        current_page : ''
    },
    methods : {
        change_hash : function(hash)
        {
            $.bbq.pushState("#"+hash);
        },
        add_hash : function(hash)
        {
            $.bbq.pushState('#'+$.param.fragment()+'/'+hash);
        },
        get_hash : function(n) {
            n--;
            var link = $.param.fragment();
            var parts = link.split('/');
            if(parts[n])
            {
                return parts[n];
            }
            else if(n > 1){
                return undefined;
            }
            else
            {
                return parts;

            }
        },
        bind_hash_events : function()
        {

        }
    },
    get_hash : function(n){
        return this.methods.get_hash(n);
    },
    add_hash : function(hash){
        return this.methods.add_hash(hash);
    },
    change_hash : function(hash){
        return this.methods.change_hash(hash);
    }
};

onsweb.data = {
    data : {
        localstorage_info : null
    },
    storage : {
        menu : null
    },
    methods : {

        get_localstorage_object : function(object_name){
            information[object_name] =  amplify.store(object_name);
        },
        get : function(object_name){
            return amplify.store(object_name);
        },
        set : function( object_name, object){
            amplify.store(object_name,object);
        },
        set_localstorage_object : function(object_name, forever){
            if(forever == true)
            {
                information[object_name].forever = true;
            }
            amplify.store(object_name, information[object_name]);
        },
        init_localstorage : function(reset){
            if(reset != true && onsweb.data.methods.check_localstorage_reset())
            {
                reset = true;
            }
            if(reset == true)
            {
                onsweb.data.methods.reset_localstorage();
                var new_appdata = null;
                /* Dummie data */
                if(onsweb.config.use_dummie_data){
                    new_appdata = data;
                } else {
                    new_appdata = onsweb.ajax.call('get_appdata');
                }
                if(new_appdata != null)
                {
                    $.each(new_appdata, function(i, data)
                    {
                        app_data[i] = data;
                    });
                }
                onsweb.console.log('localstorage reseted....');

                onsweb.data.methods.set_localstorage_information();
            }
            //var expire_date = methods.get_expire_seconds();
            $.each(app_data, function(i,item){

                if(amplify.store(i) == undefined || reset == true)
                {
                    amplify.store(i, item);
                }

            });
        },
        reset_localstorage : function(){
            var items = amplify.store();
            $.each(items, function(i, item){
                if(item.forever == undefined || item.forever != true)
                {
                    amplify.store(i, null);
                }
            });
        },
        fill_information_object : function(){
            onsweb.data.methods.check_localstorage_information();
            information = amplify.store();
            /* Delete pages, they are too heavy on mobile browsers */
            information.pages = null;
            app_data = null;
        },
        get_expire_seconds : function(){
            var d=new Date();
            var i = 7 - d.getDay();

            return i*86400;
        },
        check_localstorage_reset : function(){
            if(onsweb.config.data == undefined || onsweb.config.data.force_reset == undefined ||  onsweb.config.data.reset_update_before == undefined)
            {
                return false;
            }
            else
            {
                onsweb.data.data.localstorage_info = amplify.store('localstorage_info');

                if(onsweb.config.data.force_reset == true)
                {
                    onsweb.console.log('localstorage force reset....');
                    return true;
                }

                if( onsweb.config.data.reset_update_before == false || onsweb.data.data.localstorage_info == undefined || onsweb.data.data.localstorage_info.last_update == undefined)
                {
                    return false;
                }
                else if(onsweb.config.data.reset_update_before >= onsweb.data.data.localstorage_info.last_update)
                {
                    onsweb.console.log('localstorage force reset 2 ....');
                    return true;
                }
                else
                {
                    onsweb.console.log('localstorage is new enough ....');
                    return false;

                }
            }
            return false;
        },
        check_localstorage_information : function(){
            var curr = (new Date().getTime()); // / 1000
            onsweb.data.data.localstorage_info = amplify.store('localstorage_info');
            if(onsweb.data.data.localstorage_info == undefined || onsweb.data.data.localstorage_info.last_update == undefined )
            {
                onsweb.console.log('New so reset....');
                onsweb.data.methods.init_localstorage(true);
            }
            else if( (onsweb.data.data.localstorage_info.last_update + onsweb.data.data.localstorage_info.expire_in ) <= curr)
            {
                onsweb.console.log('localstorage expired.... update_on: '+onsweb.data.data.localstorage_info.last_update + ' expire_in: '+ onsweb.data.data.localstorage_info.expire_in + ' curr:'+ curr);
                onsweb.data.methods.init_localstorage(true);
            }

        },
        set_localstorage_information : function(){
            onsweb.data.methods.set('localstorage_info', {
                last_update : new Date().getTime(),
                expire_in : onsweb.data.methods.get_expire_seconds()
            });
        }
    },
    init : function(reset){
        this.methods.init_localstorage(reset);
        this.methods.fill_information_object();
    },
    get : function(key){
        return onsweb.data.methods.get(key,data);
    },
    set :function (key, data){
        onsweb.data.methods.set(key,data);
    }
};

onsweb.ajax = {
    /* Right now this object also holds all the ajax calls... question remains if this is a smart move or not */
    defaults : {
        url : {
            get_appdata : 'get_appdata/',
            push_translation :  'push_translation/',
            get_news_items : 'get_news_items/',
            get_news_item : 'get_news_item/',
            get_calendar_items : 'get_calendar_items/',
            get_calendar_item : 'get_calendar_item/',
            get_tournament_items : 'get_tournament_items/',
            get_tournament_item : 'get_tournament_item/',
            login : 'login/',
            get_user_info : 'get_user_info/',
            save_user_info : 'save_user_info/',
            get_app_favorites : 'competition/get_app_favorites/',
            delete_user_favorite : 'competition/delete_app_favorite/',
            add_user_favorite : 'competition/add_app_favorite/',
            get_livescore: 'competition/get_livescore/',
            get_overview : 'competition/get_overview/',
            get_match : 'competition/get_match/',
            get_passport : 'competition/get_passport/'
        }
    },
    data : {
        response : null,
        called : false
    },
    methods : {
        create_ajax_call : function(url, post_data, callback){
            onsweb.console.log('Starting ajax call. Url: '+ onsweb.config.ajax_root+url);
            var rr = null;
            $.ajax({
                async: false,
                type: 'POST',
                url: onsweb.config.ajax_root + url,
                data : post_data,
                beforeSend : function(){
                },
                success : function (r) {
                    onsweb.console.log('Ajax call done!');
                    rr = r;

                },
                error : function(jqXHR, textStatus, errorThrown){
                    /* Error ?*/
                    onsweb.console.warn('Ajax call error! Url: ' + url);
                    onsweb.console.warn(textStatus);
                    throw (errorThrown);
                }
            });
            return rr;
        }

    },
    call : function(url, data){
        if(this.defaults.url[url]){
            return this.methods.create_ajax_call(this.defaults.url[url], data);
            return this._create_ajax_call(this.defaults.url[url], data);
        } else {
            onsweb.console.warn('Could not find ajax url for url_key: '+url);
            return null;
        }
    },
    _create_ajax_call : function(url, post_data){
        onsweb.console.log('Starting ajax call. Url: '+ onsweb.config.ajax_root+url);
        var rr = null;
        var a = $.post(onsweb.config.ajax_root + url,post_data,function(r){
            onsweb.console.log(r);
            rr = r;
            return rr;
        });
        a.done(function(){
            var i = 0;
            while(rr == null){

                i++;
                if(i > 1000){
                    rr = a.responseText;
                    throw(a.responseText);
                    break;
                } else {
                    onsweb.console.log('waiting');
                }
            }
        });
        return rr;
    }
};

onsweb.console = {
    log : function(m){
        if(onsweb.config.debug_mode){
            console.log(m);
        }
    },
    warn : function(m){
        if(onsweb.config.debug_mode){
            console.warn(m);
        }
    }
};

onsweb.page_writer = {
    defaults : {
        content: '#content',
        footer: '#footer',
        header: '#header'
    },
    clear_content : function (clear_loader) {
        $(this.defaults.content).html('');
        if(clear_loader){
            onsweb.loader.stop('onsweb_object_page::fill_content');
        }
    },
    fill_content : function (html) {
        if(html != '' && html != undefined)
        {
            $(this.defaults.content).html(html).trigger('change');
        }
        else
        {
            $(this.defaults.content).html('').trigger('change');
        }
        onsweb.screen.methods.reinit_window();
        onsweb.loader.stop('onsweb_object_page::fill_content');
    },
    clear_footer : function () {
        $(this.defaults.footer).html('');
    },
    fill_footer : function (html) {
        $(this.defaults.footer).html(html);
    },
    clear_header : function () {
        $(this.defaults.header).html('');
    },
    fill_header : function (html) {
        $(this.defaults.header).html(html);
    },
    throw_404 : function (){
        onsweb.console.warn('Page not found!');
        onsweb.page_writer.fill_content('<div class="error">'+gt('Pagina niet gevonden!')+'</div>');
    }
};

onsweb.banner = {
    data : {
        current_menu_item : null,
        content : null,
        banner : null
    },
    defaults : {
        content_block : '#content',
        banner_block_class : 'o-banner-block'
    },
    set_banner : function(current_menu_item){
        onsweb.banner.data.current_menu_item = current_menu_item;
        this.select_banner();
        this.output_banner();
    },
    select_banner : function(){
        if(onsweb.banner.data.current_menu_item == undefined || onsweb.banner.data.current_menu_item.banners == undefined)
        {
            onsweb.banner.data.banner = false;
        }
        else
        {
            var items = new Array();
            $.each(onsweb.banner.data.current_menu_item.banners,function(i,item){
                items.push(item);
            });
            if(items.length == 1)
            {
                onsweb.banner.data.banner = items[0];
            }
            else
            {
                onsweb.banner.data.banner =  onsweb.banner.data.current_menu_item.banners[(Math.floor(Math.random()*items.length) + 1)];
            }
        }
    },
    output_banner : function(){
        if(onsweb.banner.data.banner != null && onsweb.banner.data.banner != false)
        {
            /* Remove items that might have gotten there by a hashchange/hack*/
            $('.'+onsweb.banner.defaults.banner_block_class).remove();

            $(onsweb.banner.defaults.content_block).append('<div class="'+onsweb.banner.defaults.banner_block_class+'"><a href="'+onsweb.banner.data.banner.link+'" target="_blank"><img src="'+onsweb.banner.data.banner.image+'" alt="'+onsweb.banner.data.banner.title+'" /></a></div>');

            $(window).trigger('resize');
        }
    }
};

onsweb.template = {
    view : function(plugin, view_name, data){
        if(onsweb.views[plugin] != undefined && onsweb.views[plugin][view_name] != undefined){
            return onsweb.views[plugin][view_name](data);
        } else {
            onsweb.console.warn('Could not load view. P:'+plugin+' V:'+view_name);
            return '';
        }
    }
};

onsweb.alert = {
	showMessage : function (message, callback, title, buttonName){

		title = title || "Melding";
		buttonName = buttonName || 'OK';

		if(navigator.notification && navigator.notification.alert){

			navigator.notification.alert(
				message,    // message
				callback,   // callback
				title,      // title
				buttonName  // buttonName
			);

		}else{

			alert(message);
			//invoke(callback)
		}

	}
}